"""
When the package has non-ascii path and .pyc file, we cannot import them.

When the path of the package has non-ascii characters, importing such
packages always fails except the first time (in other words, always 
fails when compiled .pyc file exists).

The problem exists even the names of such modules only consist of
us-ascii characters. Please follow the test code I create, which can
test the problem even with English version Windows(, I expected).

Target: Windows XP (I tested Home Ed., SP3, 32bit, Japanase version)
Python: 3.0.1

The priority of this issue might be CRITICAL or higher by 2 reasons:
1) When the end-users meet this condition, the users cannot find what's
wrong easily, because UnicodeDecodeError is raised (not ImportError).

2) On non-English version Windows, "Desktop", "My Documents" or etc. 
folders have non-English name as default. For example, Katakana is used
in Japanese version. This means all python packages in the desktop meet
 this problem for not a few users. 
"""

import sys
import os
import imp
import shutil

folders = ( ("usascii", "mymodule1"),
            ("\u30d5\u30a9\u30eb\u30c0", "mymodule2") )

print_py_content = """
def print_info():
    print ("The function print_info in", __name__, "called successfully.")
    return

"""

def recreate_empty_folder(path):
    if os.path.exists(path):        
        shutil.rmtree(path)
        print (path , "is deleted.")
    os.mkdir(path)
    print (path , "is created.")
    return

def create_my_module(child_folder_name, module_name):
    """Create new folder and module, and add path to access module.

    This function creates new folder in current folder,
    module folder in the new folder,
    and also add the new folder to sys.path.

    The module folder have empty __init__.py and print.py.
    print.py has one function defined in print_py_content."""

    new_folder = os.path.join(".", child_folder_name)
    recreate_empty_folder(new_folder)
    module_folder = os.path.join(new_folder, module_name)
    recreate_empty_folder(module_folder)
    f = open(os.path.join(module_folder, "__init__.py"), "wb")
    f.close()
    f = open(os.path.join(module_folder, "print.py"),
             "wt",
             encoding="Latin1")
    f.write(print_py_content)
    f.close()
    sys.path.append(os.path.realpath(new_folder))
    return

def call_print_print_info(module_name):
    print ("Calling " + module_name + ".print.print_info()...")
    exec("import " + module_name + ".print")
    exec(module_name + ".print.print_info()")
    print ("reload", module_name, ".")
    exec("imp.reload(" + module_name + ".print)")
    exec(module_name + ".print.print_info()")
    return

for child_f, module_n in folders:
    create_my_module(child_f, module_n)
    call_print_print_info(module_n)

print ()
print ("WARNING: When running this test script from Idle or")
print ("         interactive mode, you must completely restart")
print ("         them to re-test this issue.")
print ("Finished.")

    
    
    
